@@ -25,7 +25,7 @@ class GitlabGroup:
         self.group = group if group else (self.connection.query("groups/%s" % id)["data"] if id and token and version else None)
         self.id = self.group["id"] if self.group else None
 
-    def extract_epics(self, date_start: str = None, date_end: str = None, get_issues: bool = False, get_notes: bool = False) -> list:
+    def extract_epics(self, date_start: str = None, date_end: str = None, get_issues: bool = False, get_notes: bool = False, get_participants: bool = False) -> list:
         """
         Extract group-specific epic data.
 
@@ -34,6 +34,7 @@ class GitlabGroup:
             date_start (string): iso 8601 date value
             get_issues (boolean): TRUE if issues should be pulled
             get_notes (boolean): TRUE if notes should be pulled
+            get_participants (boolean): TRUE if participants should be pulled
 
         Returns:
             A list of GitlabEpic classes where each represents a GtiLab Epic.
@@ -56,11 +57,11 @@ class GitlabGroup:
             )
 
             # generate GitlabEpic
-            result = [GitlabEpic(epic=d, get_issues=get_issues, get_notes=get_notes) for d in epics]
+            result = [GitlabEpic(epic=d, get_issues=get_issues, get_notes=get_notes, get_participants=get_participants) for d in epics]
 
         return result
 
-    def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None, get_notes: bool = False, get_links: bool = False) -> list:
+    def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None, get_notes: bool = False, get_links: bool = False, get_participants: bool = False) -> list:
         """
         Extract group-specific epic data.
 
@@ -69,6 +70,7 @@ class GitlabGroup:
             date_start (string): iso 8601 date value
             get_links (boolean): TRUE if links should be pulled
             get_notes (boolean): TRUE if notes should be pulled
+            get_participants (boolean): TRUE if participants should be pulled
             scope (enum): all | assigned_to_me | created_by_me
 
         Returns:
@@ -93,7 +95,7 @@ class GitlabGroup:
             )
 
             # generate GitlabIssue
-            result = [GitlabIssue(issue=d, get_links=get_links, get_notes=get_notes) for d in issues]
+            result = [GitlabIssue(issue=d, get_links=get_links, get_notes=get_notes, get_participants=get_participants) for d in issues]
 
         return result
 
